@@ -4,7 +4,7 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '1.019';
+our $VERSION = '1.020';
 
 my %introduces = do { no warnings 'qw';
                  ( '5.034' => [qw[
@@ -17,7 +17,7 @@ my %introduces = do { no warnings 'qw';
                              ]],
                    '5.030' => [qw[
                                   unicode12.1 uniprop_wildcards qr'N
-                                  turkic-casing
+                                  turkic-casing ^RE_COMPILE_RECURSION_LIMIT
                              ]],
                    '5.028' => [qw[
                                  delete% unicode10.0 state@=
@@ -39,7 +39,7 @@ my %introduces = do { no warnings 'qw';
                                  s-utf8-delimiters
                               ]],
                    '5.018' => [qw[
-                                 computed-labels while-each
+                                 computed-labels while-each method-on-any-string
                               ]],
                    '5.014' => [qw[
                                  ?^ /r /d /l /u /a auto-deref
@@ -153,6 +153,7 @@ my %alias = (
     # 5.030
     'named-char-in-single-quoted-regex' => "qr'N",
     'unicode-12.1' => 'unicode12.1',
+    're-compile-recursion-limit' => '^RE_COMPILE_RECURSION_LIMIT',
     # 5.032
     'unicode-13.0' => 'unicode13.0',
     'unicode-identifier-type' => 'unicode-identifier-status',
@@ -223,7 +224,9 @@ sub import {
             ($min_version, $constr) = ($introduced{$_}, $name)
                 if $introduced{$_} gt $min_version;
         } elsif (! $removed{$_}) {
-            die "Unknown construct `$name' at ", _position(), ".\n"
+            die "Unknown construct `$name' at ",
+                _position(),
+                ". Try upgrading Syntax::Construct first.\n"
         }
 
         if ($removed{$_}) {
@@ -264,7 +267,7 @@ Syntax::Construct - Explicitly state which non-feature constructs are used in th
 
 =head1 VERSION
 
-Version 1.019
+Version 1.020
 
 =head1 SYNOPSIS
 
@@ -610,6 +613,10 @@ L<perl5180delta/Computed Labels>
 
 See in L<perl5180delta/Selected Bug Fixes> or C<each> in L<perlfunc>.
 
+=head3 method-on-any-string
+
+See [perl #105922] in L<perl5180delta/Selected Bug Fixes>.
+
 =head2 5.020
 
 =head3 attr-prototype
@@ -817,27 +824,33 @@ B<Beware:> the actual behaviour depends on the operating system's
 locale support. E.g. FreeBSD, DragonFly, and Solaris are known not to
 support it.
 
+=head3 ^RE_COMPILE_RECURSION_LIMIT
+
+Not mentioned in any Delta. See L<perlvar/${^RE_COMPILE_RECURSION_LIMIT}>.
+
+Alias: re-compile-recursion-limit
+
 =head2 5.032
 
 =head3 unicode13.0
 
-L<perldelta/Unicode 13.0 is supported>
+L<perl5320delta/Unicode 13.0 is supported>
 
 Alias: unicode-13.0
 
 =head3 chained-comparisons
 
-L<perldelta/Chained comparisons capability>
+L<perl5320delta/Chained comparisons capability>
 
 =head3 unicode-identifier-status
 
-L<perldelta/New Unicode properties Identifier_Status and Identifier_Type supported>
+L<perl5320delta/New Unicode properties Identifier_Status and Identifier_Type supported>
 
 Alias: unicode-identifier-type
 
 =head3 unicode-name-property
 
-L<It is now possible to write \p{Name=...} in perldelta|perldelta/It>
+L<It is now possible to write \p{Name=...} in perl5320delta|perl5320delta/It>
 
 =head2 5.034
 
@@ -929,10 +942,6 @@ Feel free to report issues and submit pull requests.
 
 L<https://metacpan.org/pod/Syntax::Construct>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Syntax-Construct>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Syntax-Construct>
@@ -945,7 +954,7 @@ L<http://search.cpan.org/dist/Syntax-Construct/>
 
 =head1 SEE ALSO
 
-L<Perl::MinimumVersion>
+L<Perl::MinimumVersion>, L<Perl::MinimumVersion::Fast>
 
 =head1 LICENSE AND COPYRIGHT
 
